searchData={"items":[{"type":"module","title":"BounceBack","doc":"","ref":"BounceBack.html"},{"type":"function","title":"BounceBack.execute_retry/3","doc":"","ref":"BounceBack.html#execute_retry/3"},{"type":"macro","title":"BounceBack.retry/2","doc":"","ref":"BounceBack.html#retry/2"},{"type":"module","title":"BounceBack.Examples.ExampleApp","doc":"","ref":"BounceBack.Examples.ExampleApp.html"},{"type":"function","title":"BounceBack.Examples.ExampleApp.exponential_backoff_task/0","doc":"","ref":"BounceBack.Examples.ExampleApp.html#exponential_backoff_task/0"},{"type":"function","title":"BounceBack.Examples.ExampleApp.exponential_backoff_with_jitter_task/0","doc":"","ref":"BounceBack.Examples.ExampleApp.html#exponential_backoff_with_jitter_task/0"},{"type":"function","title":"BounceBack.Examples.ExampleApp.linear_task/0","doc":"","ref":"BounceBack.Examples.ExampleApp.html#linear_task/0"},{"type":"function","title":"BounceBack.Examples.ExampleApp.retry_on_errors/0","doc":"","ref":"BounceBack.Examples.ExampleApp.html#retry_on_errors/0"},{"type":"function","title":"BounceBack.Examples.ExampleApp.retry_on_function/0","doc":"","ref":"BounceBack.Examples.ExampleApp.html#retry_on_function/0"},{"type":"module","title":"BounceBack.Examples.ExampleApp.MyError","doc":"","ref":"BounceBack.Examples.ExampleApp.MyError.html"},{"type":"module","title":"BounceBack.Strategies","doc":"Implements various retry strategies for BounceBack.","ref":"BounceBack.Strategies.html"},{"type":"function","title":"BounceBack.Strategies.wait/3","doc":"","ref":"BounceBack.Strategies.html#wait/3"},{"type":"module","title":"BounceBack.Telemetry","doc":"Telemetry events for BounceBack.","ref":"BounceBack.Telemetry.html"},{"type":"function","title":"BounceBack.Telemetry.attach_default_handler/0","doc":"","ref":"BounceBack.Telemetry.html#attach_default_handler/0"},{"type":"extras","title":"BounceBack ♻️","doc":"# BounceBack ♻️\n\n[![BounceBack](https://img.shields.io/hexpm/v/bounce_back.svg)](https://hex.pm/packages/bounce_back/0.2.0)\n\nBounceBack is an Elixir library that provides flexible retry mechanisms with customizable strategies for handling retries in the event of failures. It allows you to easily implement retry logic in your applications using a variety of strategies, such as exponential backoff and linear delay, with options for jitter to avoid congestion during retries.","ref":"readme.html"},{"type":"extras","title":"Features - BounceBack ♻️","doc":"- **Retry Mechanism**: Automatically retries failed operations with customizable retry policies.\n- **Multiple Strategies**: Built-in strategies like exponential backoff and linear delay, with the ability to extend.\n- **Customizable Options**: Control the number of retries, delay between retries, and more.\n- **Telemetry Integration**: Hooks for monitoring retry attempts and failures using Elixir's `:telemetry`.\n- **Error Handling**: Retry based on specific error types or conditions.","ref":"readme.html#features"},{"type":"extras","title":"Installation - BounceBack ♻️","doc":"Add `bounce_back` to your list of dependencies in `mix.exs`:\n\n```elixir\ndefp deps do\n  [\n    {:bounce_back, \"~> 0.2.0\"}\n  ]\nend\n```\n\nThen, run the following command to install the dependency:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - BounceBack ♻️","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Basic Retry Example - BounceBack ♻️","doc":"You can use the `BounceBack.retry/2` macro to wrap any operation you want to retry. Here's an example that retries a function that can fail, using the default options:\n\n```elixir\ndefmodule MyApp.Example do\n  import BounceBack\n\n  def some_function do\n    retry do\n      # Your code that might fail\n      IO.puts(\"Attempting operation...\")\n      {:error, :something_went_wrong}\n    end\n  end\nend\n```\n\nIn this example, the operation will be retried up to 5 times with an exponential backoff strategy if it fails.","ref":"readme.html#basic-retry-example"},{"type":"extras","title":"Customizing Retry Behavior - BounceBack ♻️","doc":"You can provide custom options to configure how retries are performed. The options include:\n\n- `:max_retries`: The maximum number of retry attempts (default: `5`).\n- `:strategy`: The retry strategy (`:exponential_backoff`, `:linear`), with default set to `:exponential_backoff`.\n- `:retry_on`: A list of error types or a function that should trigger a retry. If empty, all errors will trigger a retry (default: `[]`).\n- `:base_delay`: The base delay in milliseconds between retries (default: `100`).\n- `:jitter`: A boolean to enable/disable jitter on the delay (default: `true`).\n\n#### Example with custom options:\n\n```elixir\ndefmodule MyApp.Example do\n  import BounceBack\n\n  def some_function do\n    retry(max_retries: 3, strategy: :linear, base_delay: 200, jitter: false) do\n      IO.puts(\"Attempting operation...\")\n      {:error, :temporary_error}\n    end\n  end\nend\n```","ref":"readme.html#customizing-retry-behavior"},{"type":"extras","title":"Retry Based on Error Types - BounceBack ♻️","doc":"You can configure `:retry_on` to specify which error types or conditions should trigger a retry:\n\n```elixir\ndefmodule MyApp.Example do\n  import BounceBack\n\n  def some_function do\n    retry(retry_on: [:temporary_error]) do\n      IO.puts(\"Attempting operation...\")\n      {:error, :temporary_error}\n    end\n  end\nend\n```\n\nIn this case, the operation will only retry if the error is `:temporary_error`.","ref":"readme.html#retry-based-on-error-types"},{"type":"extras","title":"Telemetry Events - BounceBack ♻️","doc":"BounceBack integrates with Elixir's `:telemetry` system to emit events each time a retry is attempted. You can attach a default handler to listen for retry events:\n\n```elixir\nBounceBack.Telemetry.attach_default_handler()\n```\n\nThis will log the retry attempts and errors when a retry event occurs.\n\n#### Custom Telemetry Handler\n\nYou can also define your own handler for retry events. For example:\n\n```elixir\n:telemetry.attach(\n  \"my-custom-handler\",\n  [:bounce_back, :retry],\n  fn _event, measurements, metadata, _config ->\n    IO.puts(\"Retry attempt: #{inspect(measurements)}, Reason: #{inspect(metadata[:error])}\")\n  end,\n  nil\n)\n```","ref":"readme.html#telemetry-events"},{"type":"extras","title":"Retry Strategies - BounceBack ♻️","doc":"BounceBack comes with two built-in retry strategies:\n\n- **Linear**: The delay between retries increases linearly with each attempt.\n- **Exponential Backoff**: The delay doubles with each retry attempt, starting from the base delay.\n\nYou can define your own strategy by implementing a `wait/3` function in the `BounceBack.Strategies` module.","ref":"readme.html#retry-strategies"},{"type":"extras","title":"Telemetry Events for Retry Attempts - BounceBack ♻️","doc":"Whenever a retry event occurs, BounceBack emits telemetry events with the following measurements:\n\n- `remaining_retries`: The number of retries remaining before giving up.\n- `error`: The reason for the failure that triggered the retry.","ref":"readme.html#telemetry-events-for-retry-attempts"},{"type":"extras","title":"License - BounceBack ♻️","doc":"BounceBack is released under the MIT License. See the [LICENSE](LICENSE) file for more details.\n\n---\n\nThis README provides an overview of how to use the `BounceBack` library, including examples and configuration options.","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) [2024] [vicentedpsantos]\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}